<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://developers.seeka.co
 * @since      1.0.0
 *
 * @package    Seeka_WooCommerce
 * @subpackage Seeka_WooCommerce/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Seeka_WooCommerce
 * @subpackage Seeka_WooCommerce/admin
 * @author     Seeka <platform@seeka.co>
 */
class Seeka_WooCommerce_Admin
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	private $Seeka_WooCommerce_options;

	private $default_endpoint_url;

	public $update_cache_key;
	public $update_cache_allowed;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->default_endpoint_url = "https://sdk.seeka.services";
		$this->cache_key = 'Seeka_WooCommerce_custom_upd';
		$this->cache_allowed = false;
		$this->plugin_slug = plugin_basename(__DIR__);
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Seeka_WooCommerce_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Seeka_WooCommerce_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		// wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/seeka-woocommerce-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Seeka_WooCommerce_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Seeka_WooCommerce_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		// wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/seeka-woocommerce-admin.js', array( 'jquery' ), $this->version, false );

	}

	// -------------- START OPTIONS -------------------

	public function add_plugin_page()
	{
		add_options_page(
			'Seeka - WooCommerce', // page_title
			'Seeka - WooCommerce', // menu_title
			'manage_options', // capability
			'seeka-woocommerce', // menu_slug
			array($this, 'Seeka_WooCommerce_create_admin_page') // function
		);
	}

	public function Seeka_WooCommerce_create_admin_page()
	{
		$this->Seeka_WooCommerce_options = get_option('Seeka_WooCommerce_option_name');
		// $scriptTransientCacheKey = "seeka-woocommerce-cache-js-script-content";
		// delete_site_transient($scriptTransientCacheKey);
?>

		<div class="wrap">
			<h2>Seeka - WooCommerce</h2>
			<p></p>
			<?php settings_errors(); ?>

			<form method="post" action="options.php">
				<?php
				settings_fields('Seeka_WooCommerce_option_group');
				do_settings_sections('seeka-woocommerce-admin');
				submit_button();
				?>
			</form>
		</div>
	<?php }

	public function plugin_page_init()
	{
		register_setting(
			'Seeka_WooCommerce_option_group', // option_group
			'Seeka_WooCommerce_option_name', // option_name
			array($this, 'Seeka_WooCommerce_sanitize') // sanitize_callback
		);

		add_settings_section(
			'Seeka_WooCommerce_setting_section', // id
			'Settings', // title
			array($this, 'Seeka_WooCommerce_section_info'), // callback
			'seeka-woocommerce-admin' // page
		);

		add_settings_field(
			'converge_key_0', // id
			'Converge public key', // title
			array($this, 'converge_key_0_callback'), // callback
			'seeka-woocommerce-admin', // page
			'Seeka_WooCommerce_setting_section' // section
		);

		add_settings_field(
			'converge_org_0', // id
			'Organisation ID', // title
			array($this, 'converge_org_0_callback'), // callback
			'seeka-woocommerce-admin', // page
			'Seeka_WooCommerce_setting_section' // section
		);

		add_settings_field(
			'converge_endpoint_1', // id
			'Converge endpoint', // title
			array($this, 'converge_endpoint_1_callback'), // callback
			'seeka-woocommerce-admin', // page
			'Seeka_WooCommerce_setting_section' // section
		);

		add_settings_field(
			'converge_debug_mode_enabled_2', // id
			'Converge debug mode enabled', // title
			array($this, 'converge_debug_mode_enabled_2_callback'), // callback
			'seeka-woocommerce-admin', // page
			'Seeka_WooCommerce_setting_section' // section
		);

		add_settings_field(
			'converge_debug_log_level_3', // id
			'Converge debug log level', // title
			array($this, 'converge_debug_log_level_3_callback'), // callback
			'seeka-woocommerce-admin', // page
			'Seeka_WooCommerce_setting_section' // section
		);

		// add_settings_field(
		// 	'converge_custom_init_4', // id
		// 	'Converge config override', // title
		// 	array( $this, 'converge_custom_init_4_callback' ), // callback
		// 	'seeka-woocommerce-admin', // page
		// 	'Seeka_WooCommerce_setting_section' // section
		// );
	}

	public function enable_auto_updates_for_plugin($update, $item)
	{
		if ($item->slug === 'seeka-woocommerce') {
			return true; // Enable auto-update for this plugin.
		}
		return $update; // Keep the default behavior for other plugins.
	}

	public function Seeka_WooCommerce_sanitize($input)
	{
		$sanitary_values = array();

		if (isset($input['converge_key_0'])) {
			$sanitary_values['converge_key_0'] = sanitize_text_field($input['converge_key_0']);
		}

		if (isset($input['converge_org_0'])) {
			$sanitary_values['converge_org_0'] = sanitize_text_field($input['converge_org_0']);
		}

		if (isset($input['converge_endpoint_1'])) {
			$sanitary_values['converge_endpoint_1'] = sanitize_text_field($input['converge_endpoint_1']);
		}

		if (isset($input['converge_debug_mode_enabled_2'])) {
			$sanitary_values['converge_debug_mode_enabled_2'] = $input['converge_debug_mode_enabled_2'];
		}

		if (isset($input['converge_debug_log_level_3'])) {
			$sanitary_values['converge_debug_log_level_3'] = $input['converge_debug_log_level_3'];
		}

		// if ( isset( $input['converge_custom_init_4'] ) ) {
		// 	$sanitary_values['converge_custom_init_4'] = $input['converge_custom_init_4'];
		// }


		return $sanitary_values;
	}

	public function Seeka_WooCommerce_section_info() {}

	public function converge_key_0_callback()
	{
		printf(
			'<input class="regular-text" type="text" name="Seeka_WooCommerce_option_name[converge_key_0]" id="converge_key_0" value="%s">',
			isset($this->Seeka_WooCommerce_options['converge_key_0']) ? esc_attr($this->Seeka_WooCommerce_options['converge_key_0']) : ''
		);
	}

	public function converge_org_0_callback()
	{
		printf(
			'<input class="regular-text" type="text" name="Seeka_WooCommerce_option_name[converge_org_0]" id="converge_org_0" value="%s">',
			isset($this->Seeka_WooCommerce_options['converge_org_0']) ? esc_attr($this->Seeka_WooCommerce_options['converge_org_0']) : ''
		);
	}

	public function converge_endpoint_1_callback()
	{
		printf(
			'<input class="regular-text" type="text" name="Seeka_WooCommerce_option_name[converge_endpoint_1]" id="converge_endpoint_1" value="%s">',
			isset($this->Seeka_WooCommerce_options['converge_endpoint_1']) ? esc_attr($this->Seeka_WooCommerce_options['converge_endpoint_1']) : $this->default_endpoint_url
		);
	}

	// public function converge_custom_init_4_callback() {
	// 	printf(
	// 		'<textarea rows="10" cols="100" name="Seeka_WooCommerce_option_name[converge_custom_init_4]" id="converge_custom_init_4">%s</textarea>',
	// 		isset( $this->Seeka_WooCommerce_options['converge_custom_init_4'] ) ? esc_attr( $this->Seeka_WooCommerce_options['converge_custom_init_4']) : ''
	// 	);
	// }

	public function converge_debug_mode_enabled_2_callback()
	{
		printf(
			'<input type="checkbox" name="Seeka_WooCommerce_option_name[converge_debug_mode_enabled_2]" id="converge_debug_mode_enabled_2" value="converge_debug_mode_enabled_2" %s> <label for="converge_debug_mode_enabled_2">Only enable this while testing your site as it will temporarily decrease site performance while enabled.</label>',
			(isset($this->Seeka_WooCommerce_options['converge_debug_mode_enabled_2']) && $this->Seeka_WooCommerce_options['converge_debug_mode_enabled_2'] === 'converge_debug_mode_enabled_2') ? 'checked' : ''
		);
	}

	public function converge_debug_log_level_3_callback()
	{
	?> <select name="Seeka_WooCommerce_option_name[converge_debug_log_level_3]" id="converge_debug_log_level_3">
			<?php $selected = (isset($this->Seeka_WooCommerce_options['converge_debug_log_level_3']) && $this->Seeka_WooCommerce_options['converge_debug_log_level_3'] === 'error') ? 'selected' : ''; ?>
			<option <?php echo $selected; ?>>error</option>
			<?php $selected = (isset($this->Seeka_WooCommerce_options['converge_debug_log_level_3']) && $this->Seeka_WooCommerce_options['converge_debug_log_level_3'] === 'warning') ? 'selected' : ''; ?>
			<option <?php echo $selected; ?>>warning</option>
			<?php $selected = (isset($this->Seeka_WooCommerce_options['converge_debug_log_level_3']) && $this->Seeka_WooCommerce_options['converge_debug_log_level_3'] === 'information') ? 'selected' : ''; ?>
			<option <?php echo $selected; ?>>information</option>
			<?php $selected = (isset($this->Seeka_WooCommerce_options['converge_debug_log_level_3']) && $this->Seeka_WooCommerce_options['converge_debug_log_level_3'] === 'verbose') ? 'selected' : ''; ?>
			<option <?php echo $selected; ?>>verbose</option>
		</select> <?php
				}


				/* 
	* Retrieve this value with:
	* $Seeka_WooCommerce_options = get_option( 'Seeka_WooCommerce_option_name' ); // Array of All Options
	* $converge_key_0 = $Seeka_WooCommerce_options['converge_key_0']; // Converge key
	* $converge_org_0 = $Seeka_WooCommerce_options['converge_org_0']; // Organisation ID
	* $converge_endpoint_1 = $Seeka_WooCommerce_options['converge_endpoint_1']; // Converge endpoint
	* $converge_debug_mode_enabled_2 = $Seeka_WooCommerce_options['converge_debug_mode_enabled_2']; // Converge debug mode enabled
	* $converge_debug_log_level_3 = $Seeka_WooCommerce_options['converge_debug_log_level_3']; // Converge debug log level
	*/

				// -------------- FINISH OPTIONS -------------------


				// -------------- START AUTO UPDATES ------------------- from https://rudrastyh.com/wordpress/self-hosted-plugin-update.html

				public function update_request()
				{

					$remote = get_transient($this->update_cache_key);

					if (false === $remote || ! $this->update_cache_allowed) {

						$remote = wp_remote_get(
							'https://sdk.seeka.services/dist/wordpress/woocommerce/latest/info.json',
							array(
								'timeout' => 10,
								'headers' => array(
									'Accept' => 'application/json'
								)
							)
						);

						if (
							is_wp_error($remote)
							|| 200 !== wp_remote_retrieve_response_code($remote)
							|| empty(wp_remote_retrieve_body($remote))
						) {
							return false;
						}

						set_transient($this->update_cache_key, $remote, 60 * 60 * 12); // 12 hours

					}

					$remote = json_decode(wp_remote_retrieve_body($remote));

					return $remote;
				}


				function update_info($res, $action, $args)
				{

					// print_r( $action );
					// print_r( $args );

					// do nothing if you're not getting plugin information right now
					if ('plugin_information' !== $action) {
						return $res;
					}

					// do nothing if it is not our plugin
					if ($this->plugin_slug !== $args->slug) {
						return $res;
					}

					// get updates
					$remote = $this->update_request();

					if (! $remote) {
						return $res;
					}

					$res = new stdClass();

					$res->name = $remote->name;
					$res->slug = $remote->slug;
					$res->version = $remote->version;
					$res->tested = $remote->tested;
					$res->requires = $remote->requires;
					$res->author = $remote->author;
					$res->author_profile = $remote->author_profile;
					$res->download_link = $remote->download_url;
					$res->trunk = $remote->download_url;
					$res->requires_php = $remote->requires_php;
					$res->last_updated = $remote->last_updated;

					$res->sections = array(
						'description' => $remote->sections->description,
						'installation' => $remote->sections->installation,
						'changelog' => $remote->sections->changelog
					);

					if (! empty($remote->banners)) {
						$res->banners = array(
							'low' => $remote->banners->low,
							'high' => $remote->banners->high
						);
					}

					return $res;
				}

				public function update_exec($transient)
				{

					if (empty($transient->checked)) {
						return $transient;
					}

					$remote = $this->update_request();

					if (
						$remote
						&& version_compare($this->version, $remote->version, '<')
						&& version_compare($remote->requires, get_bloginfo('version'), '<=')
						&& version_compare($remote->requires_php, PHP_VERSION, '<')
					) {
						$res = new stdClass();
						$res->slug = $this->plugin_slug;
						$res->plugin = 'seeka-woocommerce/seeka-woocommerce.php'; // misha-update-plugin/misha-update-plugin.php
						$res->new_version = $remote->version;
						$res->tested = $remote->tested;
						$res->package = $remote->download_url;

						$transient->response[$res->plugin] = $res;
					}

					return $transient;
				}

				public function update_purge($upgrader, $options)
				{

					if (
						$this->update_cache_allowed
						&& 'update' === $options['action']
						&& 'plugin' === $options['type']
					) {
						// just clean the cache when new plugin version is installed
						delete_transient($this->update_cache_key);
					}
				}

				// -------------- FINISH AUTO UPDATES -------------------


			}
