<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://developers.seeka.co
 * @since             1.0.0
 * @package           Seeka_WooCommerce
 *
 * @wordpress-plugin
 * Plugin Name:       Seeka for WooCommerce
 * Plugin URI:        https://developers.seeka.co
 * Description:       Add-on to the Seeka Wordpress plugin which enables auto collection of WooCommerce events and customer data enrichment. This plugin requires the Seeka plugin to be installed and activated before activating this plugin.
 * Version:           1.0.8
 * Author:            Seeka
 * Author URI:        https://seeka.co
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       seeka-woocommerce
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'Seeka_WooCommerce_VERSION', '1.0.8' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-seeka-woocommerce-activator.php
 */
function activate_Seeka_WooCommerce() {
	if ( ! function_exists( 'get_plugins' ) || ! function_exists( 'is_plugin_active' ) ) {
		require_once ABSPATH . 'wp-admin/includes/plugin.php';
	}
	if( !is_plugin_active( 'seeka-converge/seeka-converge.php') ){
		die( 'Seeka plugin is not installed or activated. Please install and activate the Seeka plugin before activating this plugin.' );		
	}

	require_once plugin_dir_path( __FILE__ ) . 'includes/class-seeka-woocommerce-activator.php';
	Seeka_WooCommerce_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-seeka-woocommerce-deactivator.php
 */
function deactivate_Seeka_WooCommerce() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-seeka-woocommerce-deactivator.php';
	Seeka_WooCommerce_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_Seeka_WooCommerce' );
register_deactivation_hook( __FILE__, 'deactivate_Seeka_WooCommerce' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-seeka-woocommerce.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_Seeka_WooCommerce() {

	$plugin = new Seeka_WooCommerce();
	$plugin->run();

}
run_Seeka_WooCommerce();
